pypi-data
=========

Downloads *all* package metadata from PyPI.

Example: `requests metadata`__

1. Install with ``pip install pypi-data``.
2. Download pre-generated metadata with ``pypi-data init data`` (~50MB)
3. Run ``pypi-data update data`` when needed.

.. _RequestsMetadata: https://pypi.python.org/pypi/requests/json
__ RequestsMetadata_
